<?php

namespace WebkokLab\Backend;


use WebkokLab\Backend\Components\Patient\Actions;
use WebkokLab\Backend\Components\Tests\Shortcodes;
use WebkokLab\Backend\Components\User\Proxy\Profile;
use WebkokLab\Backend\Components\User\User;
use WebkokLab\Backend\Modules;


/**
 * Class Backend
 */
abstract class Backend
{
    /**
     * Main
     */
    public static function main()
    {
        add_action('admin_menu', array(__CLASS__, 'add_admin_menu'));
        add_action('init', array(__CLASS__, 'init'));
        add_action('show_user_profile', array(User::class, 'renderProfile'));
        add_action('edit_user_profile', array(User::class, 'renderProfile'));
        add_action('personal_options_update', array(Profile::class, 'save'));
        add_action('edit_user_profile_update', array(Profile::class, 'save'));
        add_action('webkok_lab_license_tasks', array(__CLASS__, 'tasks'));

        add_action('rest_api_init', function () {
            Modules\Patients\Api::routs();
        });

        self::shortcodes();
        self::hooks();
        self::roles();
    }

    /**
     * Roles
     */
    public static function roles()
    {
        $admin_role = get_role( 'administrator' );
        $admin_role->add_cap( 'webkok_lab_manage', true );
        $admin_role->add_cap( 'webkok_lab_add_test', true );
    }

    /**
     * Init
     */
    public static function init()
    {

    }


    /**
     * Shortcodes
     */
    private static function shortcodes()
    {
        Shortcodes::main();
    }

    /**
     * Actions
     */
    private static function hooks()
    {
        Actions::main();
        Modules\Tests\Actions::main();
        
        Modules\Elements\Proxy\Hooks::main();
    }

    /**
     * Admin menu.
     */
    public static function add_admin_menu()
    {
        $parent_slug = Modules\Patients\Page::slug();

        add_menu_page('Laboratory',
            __('Laboratory', 'webkok-lab'),
            'webkok_lab_add_test',
            $parent_slug,
            null,
            wpkok_lab_plugin_asset_url(__FILE__, 'img/flask.png', 'resources'));

        add_submenu_page($parent_slug,
            __('Patients', 'webkok-lab'),
            __('Patients', 'webkok-lab'),
            'webkok_lab_manage',
            $parent_slug,
            array(Modules\Patients\Page::class, 'render')
        );

        add_submenu_page(
            $parent_slug,
            __('Tests', 'webkok-lab'),
            __('Tests', 'webkok-lab'),
            'webkok_lab_add_test',
            Modules\Tests\Page::slug(),
            array(Modules\Tests\Page::class, 'render')
        );

        add_submenu_page(
            $parent_slug,
            __('Elements', 'webkok-lab'),
            __('Elements', 'webkok-lab'),
            'webkok_lab_manage',
            Modules\Elements\Page::slug(),
            array(Modules\Elements\Page::class, 'render')
        );

        add_submenu_page(
            $parent_slug,
            __('Ranges', 'webkok-lab'),
            __('Ranges', 'webkok-lab'),
            'webkok_lab_manage',
            Modules\Ranges\Page::slug(),
            array(Modules\Ranges\Page::class, 'render')
        );

        add_submenu_page(
            $parent_slug,
            __('Settings', 'webkok-lab'),
            __('Settings', 'webkok-lab'),
            'webkok_lab_manage',
            Modules\Settings\Page::slug(),
            array(Modules\Settings\Page::class, 'render')
        );
    }

    /**
     * Tasks.
     */
    public static function tasks()
    {
        License::tasks();
    }

}