<?php

namespace WebkokLab\Backend\Components\Chart\Proxy;

use Exception;
use WebkokLab\Backend\Modules\Elements\Proxy\Color;
use WebkokLab\Lib\Base\Message;
use WebkokLab\Lib\Entities\Test;
use WebkokLab\Lib\Entities\TestElement;

class HealthChart
{
    /**
     * Get dataset
     *
     * @param $user_id
     * @param null $tests_count
     * @param null $elements_count
     * @return array
     */
    public static function dataset($user_id, $tests_count = null, $elements_count = null)
    {
        try {
            if (empty($user_id)) throw new Exception(__('Not found user!', 'webkok-lab'));

            $elements = TestElement::query()
                ->order('asc')
                ->orderBy('id')
                ->limit($elements_count)
                ->get();

            $tests = Test::query()->where('user_id', $user_id)
                ->order('desc')
                ->limit($tests_count)
                ->orderBy('id')
                ->get();

            return self::generateData($elements, $tests);
        } catch (Exception $e) {
            Message::admin($e->getMessage());
        }
    }

    /**
     * Get dataset for custom elements
     *
     * @param $user_id
     * @param $ids
     * @param null $tests_count
     * @return array
     */
    public static function datasetForElements($user_id, $ids, $tests_count = null)
    {
        try {
            if (empty($user_id)) throw new Exception(__('Not found user!', 'webkok-lab'));

            $elements = TestElement::query()
                ->whereIn('id', $ids)
                ->order('asc')
                ->orderBy('id')
                ->get();

            $tests = Test::query()->where('user_id', $user_id)
                ->order('desc')
                ->limit($tests_count)
                ->orderBy('id')
                ->get();

            return self::generateData($elements, $tests);
        } catch (Exception $e) {
            Message::admin($e->getMessage());
        }
    }

    /**
     * Generate date of elements and tests items for chart dataset
     *
     * @param $elements
     * @param $tests
     * @return array
     * @throws Exception
     */
    public static function generateData($elements, $tests)
    {
        if (empty($elements) || empty($tests)) throw new Exception(__('Not found any data!', 'webkok-lab'));

        $tests = self::sortTests($tests);

        $tests_result = array();
        for ($x = 0; $x < count($tests); $x++) {    //decode database json field
            $tests_result[$x] = json_decode($tests[$x]->details, true);
        }


        $labels = $datasets = array();

        // add labels
        foreach ($tests as $test) {
            $labels[] = wpkok_lab_date($test->date);
        }

        // add dataset
        foreach ($elements as $index => $element) {
            $datasets[] = [
                'label' => $element->title,
                'data' => self::extractItemData($tests_result, $element->id),
                'fill' => false,
                'borderColor' => $element->color != null ? $element->color : Color::random(),
                'backgroundColor' => $element->color != null ? $element->color : Color::random(),
                'tension' => 0.1,
            ];
        }

        return ['datasets' => $datasets, 'labels' => $labels];
    }

    public static function extractItemData($test_results, $element_id)
    {
        try {
            $array = array();
            foreach ($test_results as $test_item) {
                if (!isset($test_item[$element_id]) || empty($test_item[$element_id])) continue;
                if (!isset($test_item[$element_id]['test_result'])) continue;
                $array[] = $test_item[$element_id]['test_result'];
            }
            return $array;
        } catch (Exception $e) {
            return [];
        }
    }

    private static function sortTests($data)
    {
        try {
            usort($data, function ($a, $b) {
                return $a->id > $b->id;
            });
            return $data;
        } catch (Exception $e) {
            return [];
        }
    }


}