<?php

namespace WebkokLab\Backend\Modules\Elements\Proxy;

use WebkokLab\Lib\Base\Message;
use WebkokLab\Lib\Entities\Condition;
use WebkokLab\Lib\Entities\TestElement;

class Table extends \WP_List_Table
{
    function __construct()
    {
        parent::__construct(array(
            'singular' => 'elements_table',
            'plural' => 'elements_table',
        ));
    }

    function column_default($item, $column_name)
    {
        return $item[$column_name];
    }

    function column_title($item): string
    {
        $color = $item["color"] != null ? $item["color"] : 'black';
        $title = "<div style='color: $color;'>{$item["title"]}</div>";

        $actions = array(
            'edit' => sprintf('<a href="?page=%s&action=edit&id=%s">%s</a>', $_REQUEST['page'], $item['id'], __('Edit', 'webkok-lab')),
            'delete' => sprintf('<a href="?page=%s&action=delete&id=%s" onclick="return confirm(\'ALERT: If you delete this element all conditions that created for this element in the Ranges, will be deleted.\nAre you sure?\')">%s</a>', $_REQUEST['page'], $item['id'], __('Delete', 'webkok-lab')),
        );

        $title = sprintf('<a href="?page=%s&action=edit&id=%s" style="color: %s">%s</a>', $_REQUEST['page'], $item['id'], $item['color']?? '', $item['title']);
        return sprintf('%s %s',
            $title,
            $this->row_actions($actions)
        );
    }

    function column_standard_range($item)
    {
        $value = $item["standard_range"];
        return apply_filters('laboratory_elements_table_standard_range', $value, $item);
    }

    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="elements_id[]" value="%s" />',
            $item['id']
        );
    }

    function get_columns($columns = null): array
    {

        return array(
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'title' => __('Title', 'webkok-lab'),
            'standard_range' => __('Standard range', 'webkok-lab'),
            'unit' => __('Unit', 'webkok-lab'),
            'id' => __('Id', 'webkok-lab'),


        );
    }

    function get_sortable_columns()
    {
        return array(

        );
    }

    function process_bulk_action()
    {
        global $wpdb, $table_prefix;
        if ('delete' === $this->current_action()) {
            $id = isset($_REQUEST['id']) ? $_REQUEST['id'] : '';
            if (empty($id)) return;
            Condition::query()->where('element_id', $id)->delete();
            TestElement::query()->where('id', $id)->delete();
        }
    }

    function prepare_items()
    {
        $per_page = 25;
        $current_page = $this->get_pagenum();
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $keyword  = isset($_POST['s']) ? trim($_POST['s']) : "";
        $keyword = trim($keyword);

        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();

        $query = TestElement::query();

        if (!empty($keyword)){
            $query->whereLike('title', $keyword)
                ->orWhereLike('standard_range', $keyword)
                ->orWhereLike('id', $keyword)
                ->orWhereLike('unit', $keyword);
        }

        $query = apply_filters('laboratory_elements_table_query', $query, $this);
        $elements = $query->get();
        $component_list = array();

        foreach ($elements as $element){
            $item = array(
                'id' => $element->id,
                'title' => $element->title,
                'standard_range' => $element->standard_range,
                'unit' => $element->unit,
                'color' => $element->color,
            );
            $item = apply_filters('laboratory_elements_table_list_item', $item, $element);
            $component_list[] = $item;
        }


        $data = array_slice($component_list, (($current_page - 1) * $per_page), $per_page);
        $this->items = $data;

        $total_items = count($elements);
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ));

    }
}