<?php

namespace WebkokLab\Backend\Modules\Patients\Proxy;

use Exception;
use WebkokLab\Lib\Base\Message;
use WebkokLab\Lib\Entities\Test;
use WebkokLab\Lib\Entities\TestElement;

class Add
{
    public static function save()
    {
        try {
            // validate
            if (empty($_POST)) return;
            if (!isset($_POST['user'])) throw new Exception(__('User validate error', 'webkok-lab'));
            $user_id = $_POST['user'];

            $user = get_user_by('ID', $user_id);
            if (empty($user)) throw new Exception(__('User validate error', 'webkok-lab'));

            // save test values
            $test_id = self::saveTest($user->ID);

            // update user meta
            self::updateUser($user->ID);

            $url = add_query_arg(array("page" => "webkok-lab-tests", "user_id" => $user->ID, 'test_id' => $test_id, 'action' => 'edit'));

            do_action('laboratory_save_patient', $user_id);
            Message::admin(sprintf(__('Test was recorded Successfully. <a href="%s">View Test</a>', 'webkok-lab'), esc_url($url)), true);

        } catch (Exception $e) {
            Message::admin($e->getMessage());
        }
    }

    private static function saveTest($user_id)
    {
        $elements = (new TestElement())->get();
        $elements_values = $_POST['elements_value'];
        if (empty($elements_values) || !is_array($elements_values)) return;

        // create list

        $details = array();
        foreach ($elements as $element) {
            if ($elements_values[$element->id] === '') continue;
            if ($elements_values[$element->id] === null) continue;
            $item = array(
                'element_id' => $element->id,
                'element_title' => $element->title,
                'element_standard_range' => $element->standard_range,
                'element_unit' => $element->unit,
                'test_result' => $elements_values[$element->id] ?? '',
            );
            $item = apply_filters('laboratory_save_test_details_item', $item, $element);
            $details[$element->id] = $item;
        }


        // save test and values
        $test_id = Test::create([
            'user_id' => $user_id,
            'date' => date("Y-m-d H:i:s"),
            'details' => json_encode($details),
            'status' => 'New'
        ]);

        return $test_id;
    }


    private static function updateUser($user_id)
    {
        update_user_meta($user_id, 'insurance_no', $_POST["insurance_no"] ?? '');
    }

}