<?php

namespace WebkokLab\Backend\Modules\Patients\Proxy;

use WebkokLab\Backend\Modules\Tests\Page;
use WebkokLab\Lib\Entities\Test;
use WebkokLab\Lib\Models\Gender;
use WebkokLab\Lib\Models\User;
use WP_User_Query;

class Table extends \WP_List_Table
{
    function __construct()
    {
        parent::__construct([
            'singular' => 'patients_table',
            'plural' => 'patients_tables',
        ]);
    }

    /**
     * Default column
     *
     * @param array|object $item
     * @param string $column_name
     * @return mixed|void
     */
    function column_default($item, $column_name)
    {
        return !empty($item[$column_name]) ? $item[$column_name] : '-';
    }

    /**
     * Gender column
     *
     * @param array|object $item
     * @return mixed|void
     */
    function column_gender($item)
    {
        return Gender::item($item['gender']);
    }

    /**
     * Column
     *
     * @param $item
     * @return string
     */
    function column_full_name($item)
    {
        $tests_slug = Page::slug();
        $current_page = \WebkokLab\Backend\Modules\Patients\Page::slug();
        $url = get_edit_user_link($item['user_id']);

        $actions = array(
            'view' => sprintf("<a href='?page=$tests_slug&action=view&user_id=%s'>%s</a>", esc_attr($item['user_id']), esc_html__('View', 'webkok-lab')),
            'edit' => sprintf("<a href='%s#test_info'>%s</a>", esc_url($url), __('Edit', 'webkok-lab')),
            'health_chart' => sprintf("<a href='?page=%s&action=chart&user_id=%s'>%s</a>", esc_attr($current_page), esc_attr($item['user_id']), esc_html__('Health Chart', 'webkok-lab')),
            'delete' => sprintf('<a href="?page=%s&action=delete&user_id=%s"  onclick="return confirm(\'Are you sure?\')">%s</a>', $current_page, $item['user_id'], __('Delete', 'webkok-lab')),
        );
        $result = '<a href="?page=' . $tests_slug . '&action=view&user_id=' . $item['user_id'] . '">' . $item['full_name'] . '</a>';
        return $result . ' ' . $this->row_actions($actions);
    }

    /**
     * Column
     *
     * @param array|object $item
     * @return string|void
     */
    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="user_id[]" value="%s" />',
            $item['user_id']
        );
    }

    function column_avatar($item)
    {
        return get_avatar($item['user_id'], 32);
    }

    function column_tests_count($item)
    {
        try {
            $result = (new Test())->where('user_id', $item['user_id'])->count();
            return sprintf('<div title="%s">%s</div>', __("Tests count", 'webkok-lab'), $result);
        } catch (\Exception $e) {
            return 0;
        }
    }

    function get_columns($columns = null)
    {

        $columns = array(
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'avatar' => '-',
            'full_name' => __('Patient', 'webkok-lab'),
            'email' => __('Email', 'webkok-lab'),
            'phone_number' => __('Phone number', 'webkok-lab'),
            'birth_date' => __('Old', 'webkok-lab'),
            'gender' => __('Gender', 'webkok-lab'),
            'tests_count' => __('Tests count', 'webkok-lab'),
        );

        return $columns;
    }

    function get_sortable_columns()
    {

    }

    function process_bulk_action()
    {
        if ('delete' == $this->current_action()) {
            $id = $_REQUEST['user_id'] ?? null;
            if (empty($id)) return;
            delete_user_meta($id, 'insurance_no');
            (new Test())->where('user_id', $_REQUEST['user_id'])->delete();
        }
    }

    function prepare_items()
    {
        $per_page = 25;
        $current_page = $this->get_pagenum();
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();


        $search_term = isset($_POST['s']) ? trim($_POST['s']) : "";

        if (!empty($search_term)) {
            $search_string = esc_attr(trim($search_term));
            $query = new WP_User_Query(array(
                'orderby ' => 'ID',
                'order' => 'DESC',
                'meta_key' => 'insurance_no',
                'meta_query' => array(
                    'relation' => 'OR',
                    array(
                        'key' => 'first_name',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    ),
                    array(
                        'key' => 'last_name',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    ),
                    array(
                        'key' => 'insurance_no',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    ),
                    array(
                        'key' => 'age',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    ),
                    array(
                        'key' => 'address',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    ),
                    array(
                        'key' => 'phone_number',
                        'value' => $search_string,
                        'compare' => 'LIKE'
                    )
                )
            ));
            $users = $query->get_results();
        } else {
            $users = get_users([
                'orderby ' => 'ID',
                'order' => 'DESC',
                'meta_key' => 'insurance_no'
            ]);
        }


        $labora_users_data = array();
        for ($j = 0; $j < count($users); $j++) {
            $labora_users_data[$j] = array(
                'full_name' => get_user_meta($users[$j]->ID, 'first_name', true) . ' ' . get_user_meta($users[$j]->ID, 'last_name', true),
                'user_id' => $users[$j]->ID,
                'date' => $users[$j]->user_registered,
                'birth_date' => get_user_meta($users[$j]->ID, User::key('birth_date'), true),
                'gender' => get_user_meta($users[$j]->ID, User::key('gender'), true),
                'phone_number' => get_user_meta($users[$j]->ID, User::key('phone_number'), true),
                'email' => $users[$j]->user_email,
            );
        }

        $data = array_slice($labora_users_data, (($current_page - 1) * $per_page), $per_page);
        $this->items = $data;



        $total_items = count($labora_users_data);
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => ceil($total_items / $per_page) // calculate pages count
        ));
    }
}