<?php

namespace WebkokLab\Backend\Modules\Ranges\Proxy;

use WebkokLab\Lib\Entities\Condition;
use WebkokLab\Lib\Entities\ConditionsGroup;
use WebkokLab\Lib\Entities\Range;

class Table extends \WP_List_Table
{
    function __construct()
    {
        parent::__construct(array(
            'singular' => 'ranges_table',
            'plural' => 'ranges_table',
        ));
    }

    function column_default($item, $column_name)
    {
        return $item[$column_name];
    }

    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="ranges_id[]" value="%s" />',
            $item['id']
        );
    }

    function column_title($item)
    {
        $current_page = \WebkokLab\Backend\Modules\Ranges\Page::slug();
        $edit_url_pattern = "<a href='?page=%s&action=edit&id=%s'>%s</a>";

        $actions = array(
            'edit' => sprintf($edit_url_pattern, $current_page, $item['id'], __('Edit', 'webkok-lab')),
            'delete' => sprintf('<a href="?page=%s&action=delete&id=%s"  onclick="return confirm(\'Are you sure?\')">%s</a>', $current_page, $item['id'], __('Delete', 'webkok-lab')),
        );

        return sprintf($edit_url_pattern, $current_page, $item['id'], $item['title']) . ' ' . $this->row_actions($actions);
    }


    function column_text($item)
    {
        return substr($item['text'] ?? '', 0, 90).'...';
    }

    function get_columns($columns = null)
    {
        $columns = array(
            'cb' => '<input type="checkbox" />',
            'title' => __('Title', 'webkok-lab'),
            'text' => __('Description', 'webkok-lab'),
            'id' => __('Id', 'webkok-lab'),
        );

        return $columns;
    }

    function get_sortable_columns()
    {
        $sortable_columns = array();
        return $sortable_columns;
    }

    function process_bulk_action()
    {
        global $wpdb, $table_prefix;
        if ('delete' === $this->current_action()) {
            $id = isset($_REQUEST['id']) ? $_REQUEST['id'] : array();
            if (empty($id)) return;

            Condition::query()
                ->innerJoin(ConditionsGroup::getTableName().' as g', 'g.id', 'group_id')
                ->where('g.range_id', $id)
                ->delete();
            ConditionsGroup::query()
                ->where('range_id', $id)
                ->delete();
            Range::query()->where('id', $id)->delete();
        }
    }

    function prepare_items()
    {
        $per_page = 25;
        $current_page = $this->get_pagenum();
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();

        $keyword  = isset($_POST['s']) ? trim($_POST['s']) : "";
        $keyword = trim($keyword);

        $query = Range::query();
        if (!empty($keyword)){
            $query->whereLike('title', $keyword)
                ->orWhereLike('description', $keyword);
        }
        $query = apply_filters('laboratory_ranges_table_query', $query, $this);
        $ranges = $query->get();

        $labora_setting = array();
        for ($i = 0; $i < count($ranges); $i++) {
            $labora_setting[$i] = array(
                'title' => $ranges[$i]->title,
                'text' => $ranges[$i]->description,
                'id' => $ranges[$i]->id,
            );
        }

        $data = array_slice($labora_setting, (($current_page - 1) * $per_page), $per_page);
        $this->items = $data;


        $total_items = count($labora_setting);
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ));


    }
}