<?php

namespace WebkokLab\Backend\Modules\Tests\Proxy;

use PHPMailer\PHPMailer\Exception;
use WebkokLab\Backend\Components\Tests\Proxy\Interpretation;
use WebkokLab\Lib\Base\Message;
use WebkokLab\Lib\Entities\Test;
use WebkokLab\Lib\Entities\TestElement;

class Edit
{
    public static function saveDetails()
    {
        try {
            if (!isset($_POST['test_id'])) return;

            $elements = TestElement::query()->get();
            if (!$elements) return;

            // Get values
            $elements_value = $_POST['elements_value'];
            $test_id = sanitize_text_field($_POST['test_id']);

            $elements_value = is_array($elements_value) ? $elements_value : array();

            // Create json field  for test details
            $test = Test::find($test_id);
            if (!$test) throw new Exception('Not found test!');

            $json_array = [];
            foreach ($elements as $key => $element) {

                $result = $elements_value[$element->id] ?? array();
                $detail = $details[$element->id] ?? array();

                if ($result === '') continue;
                if ($result === null) continue;

                $item = [
                    'element_id' => $element->id,
                    'element_title' => $detail['element_title'] ?? $element->title,
                    'element_standard_range' => $detail['element_standard_range'] ?? $element->standard_range,
                    'element_unit' => $detail['element_unit'] ?? $element->unit,
                    'test_result' => $result ?? '',
                ];

                $item = apply_filters('laboratory_save_test_details_item', $item, $element);

                $json_array[$element->id] = $item;
            }


            Test::update($test_id, [
                'details' => json_encode($json_array),
            ]);

            Message::admin(__('Test was interpreted successfully!', 'webkok-lab'), true);
        } catch (Exception $exception) {
            Message::admin($exception->getMessage());
        }
    }

    public static function saveInterpretation()
    {
        try {
            if (!isset($_POST['description'])) return;

            // validate
            $test_id = trim(sanitize_text_field($_POST['test_id']));
            $doctor_text = sanitize_post($_POST['description'] ?? null);
            if (!$test_id) return;

            // check test
            $test = Test::find($test_id);
            if (empty($test)) return;
            $status = $test->status;

            // check old status
            if ($status != 'Interpreted'){
                $status = isset($doctor_text) && !empty($doctor_text) ? 'Interpreted' : 'New';
            }

            // update test
            Test::update($test_id, [
                'doctor_interpretation' => $doctor_text,
                'status' => $status,
            ]);

            // save tests body
            self::saveTestsBody();

            // interpreted actions
            if ($status != $test->status && $status == 'Interpreted'){
                do_action('laboratory_test_interpreted', $test_id);
            }

            do_action('laboratory_test_edit_save', $test_id);

            Message::admin(__('Test was interpreted successfully!', 'webkok-lab'), true);
        } catch (Exception $exception) {
            Message::admin($exception->getMessage());
        }
    }

    /**
     * Save basic header and footer for tests
     */
    private static function saveTestsBody()
    {
        $header = sanitize_post($_POST['header'] ?? null);
        $footer = sanitize_post($_POST['footer'] ?? null);
        Interpretation::updateHeader($header);
        Interpretation::updateFooter($footer);
    }

}