<?php

namespace WebkokLab\Backend\Modules\Tests\Proxy;

use WebkokLab\Backend\Modules\Tests\Page;
use WebkokLab\Lib\Entities\Test;
use WebkokLab\Lib\Models\User;

class Table extends \WP_List_Table
{
    function __construct()
    {
        global $status, $page;

        parent::__construct(array(
            'singular' => 'tests_table',
            'plural' => 'tests_tables',
        ));
    }

    function column_default($item, $column_name)
    {
        return $item[$column_name];
    }

    function column_date($item)
    {
        $view_url = esc_url(add_query_arg(array("user_id" => $item["user_id"], 'test_id' => $item['test_id'], 'action' => 'interpretation')));
        $url = esc_url(add_query_arg(array("user_id" => $item["user_id"], 'test_id' => $item['test_id'], 'action' => 'edit')));
        $delete_url = esc_url(add_query_arg(array("user_id" => $item["user_id"], 'test_id' => $item['test_id'], 'action' => 'delete')));
        $output_url = esc_url(add_query_arg(array("user_id" => $item["user_id"], 'test_id' => $item['test_id'], 'action' => 'output')));


        $redirect_params = isset($_GET['user_id']) && !empty($_GET['user_id']) ? '&action=view&user_id=' . $_GET['user_id'] : '';
        $redirect_to = urlencode(Page::url() . $redirect_params);
        $delete_url .= '&redirect_to=' . $redirect_to;

        $actions = array(
            'id' => sprintf("<span>#%s</span>", $item['test_id']),
            'view' => sprintf("<a href='%s'>%s</a>", $view_url, esc_html__('View Interpretation', 'webkok-lab')),
            'edit' => sprintf("<a href='%s'>%s</a>", $url, esc_html__('Edit', 'webkok-lab')),
            'output' => sprintf("<a href='%s'>%s</a>", $output_url, esc_html__('Output', 'webkok-lab')),
            'delete' => sprintf('<a href="%s"  onclick="return confirm(\'Are you sure?\')">%s</a>', $delete_url, __('Delete', 'webkok-lab')),
        );

        $result = '<a href="' . $view_url . '">' . wpkok_lab_date($item['date']) . '</a>';
        return $result . ' ' . $this->row_actions($actions);
    }

    function column_id($item)
    {
        return $item['test_id'];
    }

    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="test_id[]" value="%s" />',
            $item['test_id']
        );
    }

    function column_status($item)
    {
        if ($item['status'] == 'New') {
            return '<p class="labora_new_test">' . __('New', 'webkok-lab') . '</p>';
        } else {
            return '<p class="labora_interpreted_test">' . __('Interpreted', 'webkok-lab') . '</p>';
        }
    }

    function column_user_id($item)
    {
        if (!$item['user_id']) return __('None', 'webkok-lab');

        $user_info = new User($item['user_id']);
        $url = get_edit_user_link($item['user_id']);
        return sprintf("<a href='%s#test_info'>%s</a><br/>%s", esc_url($url), $user_info->getFullName(), $user_info->email);
    }

    function get_columns($columns = null)
    {

        $columns = array(
            'cb' => '<input type="checkbox" />',
        );

        $columns['date'] = __('Date', 'webkok-lab');

        $user_id = sanitize_text_field(isset($_GET['user_id']) ? $_GET['user_id'] : null);
        if (!$user_id) {
            $columns['user_id'] = __('Patient', 'webkok-lab');
        }

        $columns['status'] = __('Status', 'webkok-lab');
        $columns['id'] = __('Id', 'webkok-lab');
        return $columns;
    }

    function get_sortable_columns()
    {
        return null;
    }

    function process_bulk_action()
    {
        if ('delete' == $this->current_action()) {
            if (!isset($_GET['test_id']) || empty($_GET['test_id'])) return null;
            Test::query()->where('id', sanitize_text_field($_GET['test_id']))->delete();
            if (isset($_GET['redirect_to']) && !empty($_GET['redirect_to'])) return wp_redirect($_GET['redirect_to']);
            return wp_redirect(Page::url());
        }
    }

    function prepare_items()
    {
        global $wpdb;
        $current_page = $this->get_pagenum();
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();

        $user_id = sanitize_text_field($_GET['user_id'] ?? null);
        $action = sanitize_text_field($_GET['action'] ?? null);
        $per_page = 25;

        $keyword = isset($_POST['s']) ? trim($_POST['s']) : "";
        $keyword = trim($keyword);

        $query = Test::query();
        if (!empty($keyword)) {
            $query->whereLike('id', $keyword);
        }

        if ($action == 'view') {
            if ($user_id) $query->where('user_id', $user_id);
        }

        $query = apply_filters('laboratory_tests_table_query', $query, $this);
        $labora_test = $query->get();

        $patient_test_list = array();
        for ($i = 0; $i < count($labora_test); $i++) {
            $patient_test_list[$i] = array(
                'test_id' => $labora_test[$i]->id,
                'date' => $labora_test[$i]->date,
                'status' => $labora_test[$i]->status,
                'user_id' => $labora_test[$i]->user_id,
            );
        }
        $data = array_slice($patient_test_list, (($current_page - 1) * $per_page), $per_page);
        $this->items = $data;

        $total_items = count($labora_test);
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => ceil($total_items / $per_page) // calculate pages count
        ));

    }
}