<?php

namespace WebkokLab\Lib;

use PHPMailer\PHPMailer\Exception;
use WebkokLab\Backend\Backend;

/**
 * Class boot
 *
 * @package WebkokLab\Lib
 */
class Boot
{
    public static $textdomain = 'webkok-lab';

    public static $main_path;

    public static $required_plugins = [

    ];

    /**
     * Run method
     *
     * @return null|void
     */
    public static function main()
    {
        self::$main_path = self::file();

        $result = self::exist_required_plugins();
        if (!$result) return self::need_plugins_message();

        add_action('plugins_loaded', array(__CLASS__, 'textdomain'));
        add_action('init', array(__CLASS__, 'init'));
        add_action('admin_init', array(__CLASS__, 'admin_init'));

        Backend::main();
    }

    /**
     * Init plugin
     */
    public static function init()
    {

    }

    /**
     * Init plugin
     */
    public static function admin_init()
    {
        self::add_script();
        Settings::admin_init();
    }

    /**
     * Add scripts
     */
    public static function add_script()
    {
        $base_url = wpkok_lab_plugin_asset_url(__FILE__, '', 'resources');

        wp_register_script('lab_admin_js', $base_url . 'js/admin.js', [], WEBKOK_LAB_VERSION);
        wp_enqueue_script('lab_admin_js');

        wp_register_script('lab_admin_chart_js', $base_url . 'js/Chart.min.js', [], WEBKOK_LAB_VERSION);
        wp_enqueue_script('lab_admin_chart_js');

        wp_register_script('lab_admin_jquery', $base_url . 'js/jquery.min.js');
        wp_enqueue_script('lab_admin_jquery');

        wp_register_script('lab_labor_js', $base_url . 'js/ajax.js', [], WEBKOK_LAB_VERSION);
        wp_enqueue_script('lab_labor_js');

        wp_register_style('lab_admin_css', $base_url . 'css/admin.css', [], WEBKOK_LAB_VERSION);
        wp_enqueue_style('lab_admin_css');

    }

    /**
     * Load textdomain
     *
     * @return void
     */
    public static function textdomain()
    {
        load_plugin_textdomain(self::$textdomain, false, dirname(plugin_basename(self::$main_path)) . '/languages/');
    }

    /**
     * Need plugins message
     *
     */
    public static function need_plugins_message()
    {
        try {
            $plugin_name = wpkok_lab_plugin_dir_name(__FILE__);
            $message = '';
            $counter = 0;
            foreach (self::$required_plugins as $key => $plugin) {
                if (!isset($plugin['url']) || !isset($plugin['name'])) continue;

                $message .= sprintf(" <a href='%s' target='_blank'>`%s`</a> ", $plugin['url'], $plugin['name']);
                if ($counter < (count(self::$required_plugins) - 1)) $message .= ' ' . __('And', self::$textdomain) . ' ';
                $counter++;
            }

            add_action('admin_notices', function () use ($plugin_name, $message) {
                echo sprintf(__("
                <div class='notice notice-error is-dismissible'>
                        <p>%s : Need %s plugins!</p>
               </div>", self::$textdomain), $plugin_name, $message);
            });

            return null;
        } catch (Exception $e) {
            return null;
        }

    }

    /**
     * Get path to plugin main file.
     */
    public static function file()
    {
        return dirname(__DIR__) . '/main.php';
    }

    /**
     * Check required plugins
     *
     * @return bool
     */
    private static function exist_required_plugins()
    {
        foreach (self::$required_plugins as $key => $path) {
            if (!is_plugin_active($key)) return false;
        }
        return true;
    }
}