<?php

namespace WebkokLab\Lib;


/**
 * Class Backend
 */
abstract class Settings
{
    public static $options_group = 'webkok-lab';
    private static $options_section = 'general_section';

    /**
     * Init
     */
    public static function get_options()
    {

        $pre_key = wpkok_lab_pre_key();

        $options = [
            [
                'key' => $pre_key . 'wl_default_pronoun',
                'description' => __('Default pronoun display before patient name if user gender is null', 'webkok-lab'),
                'label' => __('Default Pronoun', 'webkok-lab'),
                'default' => __('Mr/Miss', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'wh_man_pronoun',
                'description' => __('This pronoun display before man patient name', 'webkok-lab'),
                'label' => __('Man Pronoun', 'webkok-lab'),
                'default' => __('Sehr geehrter Herr', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'wh_female_pronoun',
                'description' => __('This pronoun display before female patient name', 'webkok-lab'),
                'label' => __('Female Pronoun', 'webkok-lab'),
                'default' => __('Sehr geehrte Frau', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'wl_default_pre_name',
                'description' => '',
                'label' => __('Default Pre Name', 'webkok-lab'),
                'default' => __('Mr/Miss', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'wh_man_pre_name',
                'description' => '',
                'label' => __('Man Pre Name', 'webkok-lab'),
                'default' => __('Mr', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'wh_female_pre_name',
                'description' => '',
                'label' => __('Female Pre Name', 'webkok-lab'),
                'default' => __('Miss', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'send_mail_before_interpretation',
                'description' => '',
                'label' => __('Are you want send email after interpreted test?', 'webkok-lab'),
                'default' => true,
                'section' => self::$options_section,
                'type' => 'checkbox',
            ],
            [
                'key' => $pre_key . 'interpretation_mail_subject',
                'description' => '',
                'label' => __('Interpreted Mail Subject', 'webkok-lab'),
                'default' => __('Your Test: #{test_id} Interpreted!', 'webkok-lab'),
                'section' => self::$options_section,
            ],
            [
                'key' => $pre_key . 'interpretation_mail_message',
                'description' => '',
                'label' => __('Interpreted Mail Message', 'webkok-lab'),
                'default' => __('Hi {user_name}<br/>Your test: #{test_id} interpreted. you can login now in your account and check that.', 'webkok-lab'),
                'section' => self::$options_section,
                'type' => 'wp_editor'
            ],
        ];

        return apply_filters('laboratory_options', $options, $pre_key);
    }

    public static function admin_init()
    {
        self::add_sections();

        self::add_options();
    }

    private static function add_options()
    {
        $options = self::get_options();

        foreach ($options as $option) {

            $section = $option['section'] ?? self::$options_section;

            register_setting(
                self::$options_group,
                $option['key'],
                [
                    'default' => $option['default'],
                ]
            );


            add_settings_field(
                $option['key'],
                $option['label'],
                array(__CLASS__, 'generate_field'),
                self::$options_group,
                $section,
                $option
            );
        }
    }

    public static function generate_field($args)
    {
        $type = $args['type'] ?? '';
        $result = '';

        if ($type == 'wp_editor') $result = self::wp_editor_field($args);
        else if ($type == 'textarea') $result = self::textarea_field($args);
        else if ($type == 'select') $result = self::select_field($args);
        else $result = self::default_field($args);

        return apply_filters('laboratory_settings_filed_html', $result);
    }

    public static function default_field($args)
    {
        $value = get_option($args['key']);
        $type = isset($args['type']) ? $args['type'] : 'text';
        $style = isset($args['style']) ? $args['style'] : '';
        $more_attr = isset($args['more_attr']) ? $args['more_attr'] : '';
        ?>
        <input
                type="<?php echo esc_attr($type); ?>"
                id="<?php echo esc_attr($args['key']); ?>"
                name="<?php echo esc_attr($args['key']); ?>"
                value="<?= esc_attr($value) ?>"
                style="<?= $style ?>"
            <?= $more_attr ?>

            <?php echo esc_attr($type == 'checkbox' && $value ? 'checked' : ''); ?>
        />
        <p class="description">
            <?= wp_kses_post_deep($args['description']); ?>
        </p>

        <?php
        return null;
    }

    private static function textarea_field($args)
    {
        $value = get_option($args['key']);
        $style = isset($args['style']) ? $args['style'] : 'width: 100%';
        $more_attr = isset($args['more_attr']) ? $args['more_attr'] : '';
        ?>
        <textarea
                rows="<?php echo esc_attr(isset($args['rows']) ? $args['rows'] : 10); ?>"
                cols="<?php echo esc_attr(isset($args['cols']) ? $args['cols'] : 15); ?>"
                id="<?php echo esc_attr($args['key']); ?>"
                name="<?php echo esc_attr($args['key']); ?>"
                style="<?= $style ?>"
                <?= $more_attr ?>
        ><?= $value ?></textarea>
        <p class="description">
            <?= wp_kses_post_deep($args['description']); ?>
        </p>
        <?php
        return null;
    }

    private static function wp_editor_field($args)
    {
        $value = get_option($args['key']);
        ?>

        <?php wp_editor($value, $args['key'], ['textarea_rows' => isset($args['rows']) ? $args['rows'] : 8]); ?>

        <p class="description">
            <?= wp_kses_post_deep($args['description']); ?>
        </p>
        <?php
        return null;
    }

    private static function add_sections()
    {
        $sections = [
            self::$options_section => [
                'title' => null,
                'callback' => null,
            ]
        ];
        $sections = apply_filters('laboratory_settings_sections', $sections);

        foreach ($sections as $index => $section) {
            $title = isset($section['title']) ? $section['title'] : null;
            $callback = isset($section['callback']) ? $section['callback'] : null;
            $key = !is_array($section) ? $section : $index;

            add_settings_section(
                $key,
                $title,
                $callback,
                'webkok-lab'
            );
        }
    }

    private static function select_field($args)
    {
        $value = get_option($args['key']);
        $select_options = isset($args['select_options']) ? $args['select_options'] : [];
        $style = isset($args['style']) ? $args['style'] : '';
        $more_attr = isset($args['more_attr']) ? $args['more_attr'] : '';

        ?>
        <select
                id="<?php echo esc_attr($args['key']); ?>"
                name="<?php echo esc_attr($args['key']); ?>"
                style="<?= $style ?>"
                <?= $more_attr ?>
        >
            <?php foreach ($select_options as $key => $option): ?>
                <option value="<?= $key ?>" <?= $value == $key ? 'selected' : '' ?>>
                    <?= $option ?>
                </option>
            <?php endforeach; ?>
        </select>
        <p class="description">
            <?= wp_kses_post_deep($args['description']); ?>
        </p>
        <?php
        return null;
    }


}