<?php


namespace WebkokLab\Lib\Base;

use WebkokLab\Lib\boot;

/**
 * Class Component
 */
abstract class Component
{
    protected static $class_file;

    /**
     * Get admin page slug.
     *
     * @return string
     */
    public static function slug()
    {
        return boot::$textdomain . '-' . str_replace('_', '-', basename(static::directory()));
    }

    /**
     * Get admin page url.
     *
     * @return string
     */
    public static function url($params = null)
    {
        $query = !empty($params) ? '&' . $params : '';
        return admin_url('admin.php?page=' . self::slug() . $query);
    }

    /**
     * Render a template file.
     *
     * @param string $template
     * @param array $variables
     * @param bool $echo
     * @return void|string
     */
    public static function renderTemplate($template, $variables = array(), $echo = true)
    {
        extract(array('self' => get_called_class()));
        extract($variables);


        ob_start();
        ob_implicit_flush(0);

        include static::directory() . '/templates/' . $template . '.php';

        if (!$echo) {
            return ob_get_clean();
        }

        echo ob_get_clean();
    }

    /**
     * Get path to component directory.
     *
     * @return string
     */
    protected static function directory()
    {
        return dirname(static::$class_file);
    }


}