<?php


namespace WebkokLab\Lib\Base;


class Plugin
{

    /**
     * Get plugin dir name
     */
    public static function dir_name($file)
    {
        try {
            $start = "~plugins/";
            $end = '/~i';
            $split = '/';

            if (strpos($file, 'plugins\\') !== false) {
                $start = "~plugins\\\\";
                $end = '\\\\~i';
                $split = '\\';
            }

            preg_match("$start([^{]*)$end", $file, $match);
            if (count($match) < 2) throw new \Exception('Not found!');
            $result = $match[1];

            if (strpos($file, $split) !== false) $result = explode($split, $result);

            return $result[0];
        } catch (\Exception $e) {
            return null;
        }
    }

    /**
     * Get plugin path
     */
    public static function path($file)
    {
        try {
            $dir_name = self::dir_name($file);
            if (!$dir_name) return null;
            return path_join(WP_PLUGIN_DIR, $dir_name);
        } catch (\Exception $e) {
            return null;
        }
    }

    /**
     * Get plugin template
     */
    public static function template($file, $filename)
    {
        try {
            $path = self::path($file);
            $path = path_join($path, 'templates');
            return path_join($path, $filename);
        } catch (\Exception $e) {
            return null;
        }
    }

    /**
     * Get plugin asset dir
     */
    public static function asset($file, $filename)
    {
        try {
            $path = self::path($file);
            $path = path_join($path, 'asset');
            return path_join($path, $filename);
        } catch (\Exception $e) {
            return null;
        }
    }

    /**
     * Get plugin asset url
     */
    public static function asset_url($file, $filename)
    {
        try {
            $path = self::path($file);
            $path = path_join($path, 'main.php');
            $path = path_join(plugin_dir_url($path), 'assets');
            return path_join($path, $filename);
        } catch (\Exception $e) {
            return null;
        }
    }

}

