<?php
if (function_exists('wpkok_lab_pre_key')) return;

function wpkok_lab_pre_key()
{
    return '_wpkok_';
}

/**
 * Get a option value
 *
 * @param $key
 * @return null
 */
function wpkok_lab_get_option($key)
{
    try {
        return get_option(wpkok_lab_pre_key() . $key);
    } catch (Exception $e) {
        return null;
    }
}

/**
 * This method get a order staff list
 * of booking items. this method use Bookly plugin.
 *
 * @param $message
 * @param bool $success
 * @param string $plugin
 * @return null
 */
function wpkok_lab_show_admin_message($message, $success = false, $plugin = 'Webhead Core')
{
    try {
        add_action('admin_notices', function () use ($message, $success, $plugin) {
            echo "<div class='notice notice-" . ($success ? 'success' : 'error') . " is-dismissible'><p>$plugin: " . $message . "</p></div>";
        });
    } catch (Exception $e) {
        // log this error!
    }
}

/**
 * Get plugin dir name
 */
function wpkok_lab_plugin_dir_name($file)
{
    try {
        $start = "~plugins/";
        $end = '/~i';
        $split = '/';

        if (strpos($file, 'plugins\\') !== false) {
            $start = "~plugins\\\\";
            $end = '\\\\~i';
            $split = '\\';
        }

        preg_match("$start([^{]*)$end", $file, $match);
        if (count($match) < 2) throw new Exception('Not found!');
        $result = $match[1];

        if (strpos($file, $split) !== false) $result = explode($split, $result);

        return $result[0];
    } catch (Exception $e) {
        return null;
    }
}

/**
 * Get plugin path
 */
function wpkok_lab_plugin_path($file)
{
    try {
        $dir_name = wpkok_lab_plugin_dir_name($file);
        if (!$dir_name) return null;
        return path_join(WP_PLUGIN_DIR, $dir_name);
    } catch (Exception $e) {
        return null;
    }
}

/**
 * Get plugin asset url
 */
function wpkok_lab_plugin_asset_url($file, $filename, $assets_dir = 'assets')
{
    try {
        $path = wpkok_lab_plugin_path($file);
        $path = path_join($path, 'main.php');
        $path = path_join(plugin_dir_url($path), $assets_dir);
        return path_join($path, $filename);
    } catch (Exception $e) {
        return null;
    }
}

/**
 * Get plugin asset url
 */
function wpkok_lab_date($time, $format = null)
{
    try {

        $format = !empty($format) ? $format : 'F j, Y H:i:s';
        if (!is_numeric($time)) $time = strtotime($time);
        if (get_locale() != 'fa_IR') throw new Exception('It is not Persian!');
        if (!function_exists('webkok_lab_jdate')) throw new Exception('Not found jDate function!');
        return webkok_lab_jdate($format, $time);
    } catch (Exception $e) {
        if (!is_numeric($time)) $time = strtotime($time);
        $format = !empty($format) ? $format : 'F j, Y H:i:s';
        return wp_date($format, $time);
    }
}

/**
 * Get test status text
 */
function wpkok_lab_test_status($status)
{
    try {
        return $status == 'Interpreted' ? __('Interpreted', 'webkok-lab') : __('New', 'webkok-lab');
    } catch (Exception $e) {
        return $status;
    }
}

/**
 * Update laboratory option value
 *
 * @param $key
 * @param $value
 * @return null
 */
function wpkok_lab_update_option($key, $value)
{
    try {
        return update_option(wpkok_lab_pre_key() . $key, $value);
    } catch (Exception $e) {
        return null;
    }
}


/**
 * Online Document url
 *
 * @param $key
 * @param $value
 * @return null
 */
function wpkok_lab_doc_url()
{
    return 'https://lab.demo.wpkok.com/document';
}

/**
 * Online add-ons url
 *
 * @param $key
 * @param $value
 * @return null
 */
function wpkok_lab_add_on_url()
{
    return 'https://lab.demo.wpkok.com/add-ons';
}