<?php


namespace WebkokLab\Lib\Entities;

use WebkokLab\Lib\Base\Entity;

class Range extends Entity
{
    static $table = 'webkok_lab_ranges';

    static $columns = [
        'id',
        'title',
        'description',
    ];


    /**
     * Get with groups
     *
     * @return array
     */
    public function getWithGroups(): array
    {
        $items = $this->get();
        $result = array();
        foreach ($items as $item) {
            $result[] = self::getGroups($item);
        }
        return $result;
    }

    /**
     * get with groups
     *
     * @param $id
     * @return array|object|null
     */
    public static function findWithGroups($id)
    {
        $range = self::query()->where('id', $id)->first();
        if (!$range) return null;
        $range = self::getGroups($range);
        return apply_filters('laboratory_find_range_with_groups', $range);

    }

    /**
     * Get groups
     *
     * @param $range
     * @return array|object|null
     */
    public static function getGroups($range)
    {
        $range->groups = ConditionsGroup::query()->where('range_id', $range->id)->order('asc')->get();
        if (!$range->groups || !is_array($range->groups)) return $range;
        foreach ($range->groups as $key => $group) {
            if (!$group || !isset($group->id)) continue;
            $range->groups[$key]->conditions = Condition::query()->where('group_id', $group->id)->order('asc')->get();
        }
        return $range;
    }
}