<?php

namespace WebkokLab\Lib\Models;

use Bookly\Backend\Modules\Shop\Page;
use Exception;
use WebkokLab\Lib\Entities\Condition;
use WebkokLab\Lib\Entities\ConditionsGroup;

class Range
{
    public static function generate($component_id, $test_result)
    {
        return 'Todo fix that!';
//        global $wpdb, $table_prefix;
//        $result = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$table_prefix}labora_component_description WHERE component_id = %d AND min <= %d AND max >= %d", $component_id, $test_result, $test_result));
//
//        if (!$result) return __("didn`t set auto description for this range yet!", 'webkok-lab');
//
//        $description = '';
//        foreach ($result as $index => $item) {
//            $description = $description . $item->description;
//            if (isset($result[$index + 1])) $description = $description . ", ";
//        }
//        return $description;
    }

    /**
     * Update or create range with conditions
     *
     * @return array|false
     * @throws Exception
     */
    public static function save()
    {
        if (!isset($_POST)) return false;
        $range_id = self::saveRange();
        list($groups_ids, $conditions_ids) = self::saveGroups($range_id);
        self::deleteUnusedGroups($range_id, $groups_ids, $conditions_ids);
        do_action('laboratory_save_range', $range_id);
        return $range_id;
    }

    /**
     * Save groups
     *
     * @param $range_id
     * @return array
     * @throws Exception
     */
    private static function saveGroups($range_id): array
    {
        $operators = $_POST['operators'] ?? null;
        $amounts = $_POST['amounts'] ?? null;
        $gates = $_POST['gates'] ?? null;
        $groups_gates = $_POST['groups_gates'] ?? null;
        $elements = $_POST['elements'] ?? null;
        $ids = $_POST['ids'] ?? null;
        $groups_ids = $_POST['groups_ids'] ?? null;

        if (!$operators || !$amounts || !$gates || !$groups_gates || !$elements) throw new Exception('Please add a condition for this range');
        if (!is_array($groups_gates)) throw new Exception('Validate Error!');
        if (!$range_id) throw new Exception('Range not created!');

        $result_groups_ids = array();
        $result_conditions_ids = array();
        foreach ($groups_gates as $index => $groups_gate) {

            // save group
            if (!isset($elements[$index]) || empty($elements[$index])) continue;

            $result_groups_ids[] = $group_id = self::saveGroup($range_id, $groups_gate, $groups_ids[$index]);

            // save group conditions
            $data = array(
                'elements' => $elements[$index] ?? array(),
                'amounts' => $amounts[$index] ?? array(),
                'operators' => $operators[$index] ?? array(),
                'gates' => $gates[$index] ?? array(),
                'ids' => $ids ?? array(),
            );
            $result = self::saveConditions($group_id, $index, $data);
            array_push($result_conditions_ids, ...$result);
        }

        return array($result_groups_ids, $result_conditions_ids);
    }

    /**
     * Save group
     *
     * @param $range_id
     * @param $gate
     * @param null $id
     * @return false|int
     * @throws Exception
     */
    private static function saveGroup($range_id, $gate, $id = null)
    {
        try {
            // update
            if (isset($id) && is_numeric($id)) {
                ConditionsGroup::update($id, [
                    'range_id' => $range_id,
                    'gate' => $gate,
                ]);
                return $id;
            }

            // create
            return ConditionsGroup::create([
                'range_id' => $range_id,
                'gate' => $gate,
            ]);
        } catch (Exception $e) {
            throw new Exception('Can not create group!');
        }
    }

    /**
     * Save conditions
     *
     * @param $group_id
     * @param array $data
     * @return array|false
     */
    private static function saveConditions($group_id, $group_number, array $data)
    {
        // check data
        if (!isset($data['ids'][$group_number])) return [];
        $conditions_ids = $data['ids'][$group_number];
        if (empty($conditions_ids)) return [];

        $result = array();
        foreach ($data['elements'] as $index => $element) {
            if (empty($element)) continue;
            if (!isset($conditions_ids[$index])) continue;
            $conditions_id = $conditions_ids[$index];

            // update condition
            if (is_numeric($conditions_id)) {
                Condition::update($conditions_ids[$index], [
                    'group_id' => $group_id,
                    'element_id' => $element,
                    'amount' => $data['amounts'][$index] ?? null,
                    'operator' => $data['operators'][$index] ?? '=',
                    'gate' => $data['gates'][$index] ?? 'AND',
                ]);
                $result[] = $conditions_id;
                continue;
            }

            // create condition
            $result[] = Condition::create([
                'group_id' => $group_id,
                'element_id' => $element,
                'amount' => $data['amounts'][$index] ?? null,
                'operator' => $data['operators'][$index] ?? '=',
                'gate' => $data['gates'][$index] ?? 'AND',
            ]);
        }
        return $result;
    }

    /**
     * Save range
     *
     * @return false|int|string
     */
    private static function saveRange()
    {
        $range_id = sanitize_text_field($_GET['id'] ?? null);
        if (!empty($range_id)) {
            \WebkokLab\Lib\Entities\Range::update($range_id,
                array(
                    'title' => sanitize_text_field($_POST['title']),
                    'description' => sanitize_post($_POST['description']),
                )
            );
            return $range_id;
        }


        return \WebkokLab\Lib\Entities\Range::create(
            array(
                'title' => $_POST['title'],
                'description' => $_POST['description']
            )
        );

    }

    /**
     * Delete unused groups and conditions for this range
     *
     * @param $range_id
     * @param $groups_ids
     * @param $conditions_ids
     * @throws Exception
     */
    private static function deleteUnusedGroups($range_id, $groups_ids, $conditions_ids)
    {
        if (!$range_id) return;
        if (!is_array($groups_ids)) return;
        Condition::$columns[] = 'g.range_id';

        Condition::query()
            ->innerJoin(ConditionsGroup::getTableName().' as g', 'g.id', 'group_id')
            ->where('g.range_id', $range_id)
            ->whereNoIn('id', $conditions_ids)
            ->delete();
        /*
        Condition::query()
            ->innerJoin(ConditionsGroup::getTableName().' as g', 'g.id', 'group_id')
            ->where('g.range_id', $range_id)
            ->whereNoIn('group_id', $groups_ids)
            ->whereNoIn('id', $conditions_ids)
            ->delete();*/

        ConditionsGroup::query()
            ->where('range_id', $range_id)
            ->whereNoIn('id', $groups_ids)
            ->delete();
    }

}