<?php

namespace WebkokLab\Lib\Models;

class User
{
    public $id;
    public $email;
    public $name;
    public $family;
    public $birth_date;
    public $gender;
    public $password;
    public $phone_number;
    public $address;
    public $pronoun;
    public $pre_name;

    public static $user_meta_pre = '_webkok_';

    /**
     * User constructor.
     *
     * @param null $user
     */
    public function __construct($user = null)
    {
        if (is_numeric($user)) $user = get_user_by('ID', $user);
        if (!is_a($user, 'WP_User')) return;

        $this->id = $user->ID;
        $this->email = $user->user_email;
        $this->name = $user->first_name;
        $this->family = $user->last_name;

        $this->loadBirthDate();
        $this->loadGender();
        $this->loadPhoneNumber();
        $this->loadAddress();

        $this->loadPronoun();
        $this->loadPreName();
    }

    public function getPre($key)
    {
        return static::$user_meta_pre . $key;
    }

    public static function key($key)
    {
        return static::$user_meta_pre . $key;
    }

    public function loadBirthDate()
    {
        if (empty($this->id)) return;
        $this->birth_date = get_user_meta($this->id, $this->getPre('birth_date'), true);
    }

    public function loadGender()
    {
        if (empty($this->id)) return;
        $this->gender = get_user_meta($this->id, $this->getPre('gender'), true);
    }

    public function loadPronoun()
    {
        if (empty($this->id)) return;

        switch ($this->gender) {
            case 'men':
                $key = 'wh_man_pronoun';
                break;
            case 'female':
                $key = 'wh_female_pronoun';
                break;
            default:
                $key = 'wl_default_pronoun';
        }

        $this->pronoun = wpkok_lab_get_option($key);
    }

    public function loadPreName()
    {
        if (empty($this->id)) return;

        switch ($this->gender) {
            case 'men':
                $key = 'wh_man_pre_name';
                break;
            case 'female':
                $key = 'wh_female_pre_name';
                break;
            default:
                $key = 'wl_default_pre_name';
        }

        $this->pre_name = wpkok_lab_get_option($key);
    }

    public function loadPhoneNumber()
    {
        if (empty($this->id)) return;
        $this->phone_number = get_user_meta($this->id, $this->getPre('phone_number'), true);
    }

    public function loadAddress()
    {
        if (empty($this->id)) return;
        $this->address = get_user_meta($this->id, $this->getPre('address'), true);
    }

    public function getGender()
    {
        if (empty($this->id)) return '';
        return Gender::item($this->gender);
    }

    public function getAddressInLines()
    {
        if (empty($this->id)) return '';
        if (empty($this->address)) return '';
        return str_replace(',', '<br/>', $this->address);
    }

    public function getFullName()
    {
        if (empty($this->id)) return '';
        return $this->name. ' '. $this->family;
    }
}