function labora_notice_action() {
    document.getElementsByClassName("notice").style.display = 'none';
}

class ConditionData {
    id;
    element_id;
    operator = '=';
    amount;
    gate = 'AND';

    constructor(data) {
        if (!data) return;
        this.id = data['id'] ?? null;
        this.element_id = data['element_id'] ?? null;
        this.operator = data['operator'] ?? null;
        this.amount = data['amount'] ?? null;
        this.gate = data['gate'] ?? null;
    }
}

class RangeConditions {
    group_number = null;
    conditions = [];

    constructor(group_number) {
        this.group_number = group_number;

    }

    add(data = null) {
        data = new ConditionData(data);
        let number = data.id == null ? RangeConditions.unique_number() : data.id;
        let text = this.#condition_template(number)
        $('#wl-conditions-' + this.group_number).append(text)
        this.conditions[number] = $('#wl-condition-' + number);
        this.setInputsData(number, data);
    }

    setInputsData(number, data) {
        this.setElement(number, data);
        this.setOperator(number, data);
        this.setAmount(number, data);
        this.setGate(number, data);
    }

    setElement(number, data) {
        try {
            $("#select-element-" + number).val(data.element_id);
        } catch (e) {
        }
    }

    setOperator(number, data) {
        try {
            $("#select-operator-" + number).val(data.operator);
        } catch (e) {
        }
    }

    setAmount(number, data) {
        try {
            $("#input-amount-" + number).val(data.amount);
        } catch (e) {
        }
    }

    setGate(number, data) {
        try {
            $("#select-gate-" + number).val(data.gate);
        } catch (e) {
        }
    }

    setId(number, data) {
        try {
            $("#input-id-" + number).val(data.gate);
        } catch (e) {
        }
    }


    remove() {
        $('#wl-group-' + this.group_number).remove();
    }

    remove_condition(condition_number) {
        this.conditions[condition_number].remove();
        delete this.conditions[condition_number];
    }


    generate() {
        $('#wl-groups').append(this.#group_template())
    }

    #group_template() {
        let template = $('#wl-group-template');
        let text = template.html();
        text = text.replaceAll('_GROUP_NUMBER', this.group_number);
        return text;
    }

    #condition_template(number) {
        let template = $('#wl-condition-template');
        let text = template.html();
        text = text.replaceAll('_CONDITION_NUMBER', number);
        text = text.replaceAll('_GROUP_NUMBER', this.group_number);
        return text;
    }

    static unique_number() {
        let result = 'new_' + Date.now() + Math.random();
        return result.replaceAll('.', '_');
    }
}

/**
 * Range Groups Class
 */
class RangeGroups {

    groups = [];

    constructor(data = null) {
        if (data != null && Array.isArray(data) && data.length != 0) {

            for (let i = 0; i < data.length; i++) {
                let group = data[i];
                if (group == null) continue;
                let group_number = this.add(group['id'] ?? null);
                this.setGate(group_number, group['gate'] ?? null)
                if ("conditions" in group) {
                    let conditions = group["conditions"];
                    for (let j = 0; j < conditions.length; j++) {
                        this.add_condition(group_number, conditions[j])
                    }
                }
            }
            return;
        }

        let group_number = this.add();
        this.add_condition(group_number)

    }

    add(number) {
        if (number == null) number = RangeGroups.unique_number();
        this.groups[number] = new RangeConditions(number);
        this.groups[number].generate();
        return number;
    }

    setGate(number, gate) {
        try {
            $("#select-group-gate-" + number).val(gate);
        } catch (e) {
        }
    }


    remove(group_number) {
        this.groups[group_number].remove();
        delete this.groups[group_number];
    }

    add_condition(group_number, data = null) {
        try {
            this.groups[group_number].add(data);
        } catch (e) {
            console.error(e);
        }
    }

    remove_condition(group_number, condition_number) {
        try {
            this.groups[group_number].remove_condition(condition_number);
        } catch (e) {
            console.error(e);
        }
    }


    static unique_number() {
        let result = 'new_' + Date.now() + Math.random();
        return result.replaceAll('.', '_');
    }

}